================
``index`` module
================

.. automodule:: whoosh.index


Functions
=========

.. autofunction:: create_in
.. autofunction:: open_dir
.. autofunction:: exists_in
.. autofunction:: exists
.. autofunction:: version_in
.. autofunction:: version


Base class
==========

.. autoclass:: Index
    :members:


Implementation
==============

.. autoclass:: FileIndex


Exceptions
==========

.. autoexception:: LockError
.. autoexception:: IndexError
.. autoexception:: IndexVersionError
.. autoexception:: OutOfDateError
.. autoexception:: EmptyIndexError
